@@ -34,7 +34,7 @@ class TelePayAsyncClient:
     async def __aenter__(self) -> "TelePayAsyncClient":
         return self
 
-    async def __aexit__(self, exc_t, exc_v, exc_tb) -> None:
+    async def __aexit__(self, exc_type, exc_val, exc_tb) -> None:
         await self.close()
 
     async def close(self) -> None:
@@ -161,6 +161,26 @@ class TelePayAsyncClient:
         validate_response(response)
         return response.json()
 
+    async def get_withdraw_minimum(
+        self,
+        asset: str,
+        blockchain: str,
+        network: str = None,
+    ) -> dict:
+        """
+        Get minimum withdraw amount.
+        """
+        response = await self.http_client.post(
+            "getWithdrawMinimum",
+            json={
+                "asset": asset,
+                "blockchain": blockchain,
+                "network": network,
+            },
+        )
+        validate_response(response)
+        return response.json()
+
     async def get_withdraw_fee(
         self,
         asset: str,
