@@ -34,7 +34,7 @@ class TelePaySyncClient:
     def __enter__(self) -> "TelePaySyncClient":
         return self
 
-    def __exit__(self) -> None:
+    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
         self.close()
 
     def close(self) -> None:
@@ -161,6 +161,26 @@ class TelePaySyncClient:
         validate_response(response)
         return response.json()
 
+    def get_withdraw_minimum(
+        self,
+        asset: str,
+        blockchain: str,
+        network: str = None,
+    ) -> dict:
+        """
+        Get minimum withdraw amount.
+        """
+        response = self.http_client.post(
+            "getWithdrawMinimum",
+            json={
+                "asset": asset,
+                "blockchain": blockchain,
+                "network": network,
+            },
+        )
+        validate_response(response)
+        return response.json()
+
     def get_withdraw_fee(
         self,
         to_address: str,
